@@ -15,30 +15,30 @@
 # limitations under the License.
 
 #' It creates columns to indicate overlap information between two tables
+#' `r lifecycle::badge("deprecated")`
 #'
-#' @param x Table with individuals in the cdm
-#' @param cdm A cdm_reference object.
-#' @param tableName name of the cohort that we want to check for overlap
+#' @param x Table with individuals in the cdm.
+#' @param tableName name of the cohort that we want to check for overlap.
 #' @param filterVariable the variable that we are going to use to filter (e.g.
-#' cohort_definition_id)
+#' cohort_definition_id).
 #' @param filterId the value of filterVariable that we are interested in, it can
-#' be a vector
+#' be a vector.
 #' @param idName the name of each filterId, must have same length than
-#' filterId
-#' @param value value of interest to add: it can be count, flag, date or time
-#' @param window window to consider events of
+#' filterId.
+#' @param value value of interest to add: it can be count, flag, date or time.
+#' @param window window to consider events of.
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
-#' @param censorDate whether to censor overlap events at a date column of x
+#' @param censorDate whether to censor overlap events at a date column of x.
 #' @param targetStartDate date of reference in cohort table, either for start
-#' (in overlap) or on its own (for incidence)
+#' (in overlap) or on its own (for incidence).
 #' @param targetEndDate date of reference in cohort table, either for end
-#' (overlap) or NULL (if incidence)
-#' @param order last or first date to use for date/time calculations
+#' (overlap) or NULL (if incidence).
+#' @param order last or first date to use for date/time calculations.
 #' @param nameStyle naming of the added column or columns, should include
-#' required parameters
+#' required parameters.
 #'
-#' @return table with added columns with overlap information
+#' @return table with added columns with overlap information.
 #'
 #' @export
 #'
@@ -50,10 +50,10 @@
 #' result <- cdm$cohort1 %>%
 #'   addIntersect(tableName = "cohort2", value = "date") %>%
 #'   dplyr::collect()
+#' CDMConnector::cdmDisconnect(cdm = cdm)
 #' }
 #'
 addIntersect <- function(x,
-                         cdm = lifecycle::deprecated(),
                          tableName,
                          value,
                          filterVariable = NULL,
@@ -66,12 +66,36 @@ addIntersect <- function(x,
                          targetEndDate = endDateColumn(tableName),
                          order = "first",
                          nameStyle = "{value}_{id_name}_{window_name}") {
-  if (lifecycle::is_present(cdm)) {
-    lifecycle::deprecate_warn("0.6.0", "addIntersect(cdm)")
-  }
+  lifecycle::deprecate_warn("0.7.0", "addIntersect()")
+  .addIntersect(
+    x = x, tableName = tableName, value = value,
+    filterVariable = filterVariable, filterId = filterId, idName = idName,
+    window = window, indexDate = indexDate, censorDate = censorDate,
+    targetStartDate = targetStartDate, targetEndDate = targetEndDate,
+    order = order, nameStyle = nameStyle
+  )
+}
+
+.addIntersect <- function(x,
+                         tableName,
+                         value,
+                         filterVariable = NULL,
+                         filterId = NULL,
+                         idName = NULL,
+                         window = list(c(0, Inf)),
+                         indexDate = "cohort_start_date",
+                         censorDate = NULL,
+                         targetStartDate = startDateColumn(tableName),
+                         targetEndDate = endDateColumn(tableName),
+                         order = "first",
+                         nameStyle = "{value}_{id_name}_{window_name}") {
   if (!is.list(window)) {
     window <- list(window)
   }
+
+  targetStartDate <- eval(targetStartDate)
+  targetEndDate <- eval(targetEndDate)
+
   cdm <- omopgenerics::cdmReference(x)
   # initial checks
   personVariable <- checkX(x)
@@ -80,12 +104,11 @@ addIntersect <- function(x,
   personVariableTable <- checkX(cdm[[tableName]])
   extraValue <- checkValue(value, cdm[[tableName]], tableName)
   filterTbl <- checkFilter(filterVariable, filterId, idName, cdm[[tableName]])
-  windowTbl <- checkWindow(window)
+  window <- checkWindow(window)
   checkVariableInX(indexDate, x)
   checkVariableInX(targetStartDate, cdm[[tableName]], FALSE, "targetStartDate")
   checkVariableInX(targetEndDate, cdm[[tableName]], TRUE, "targetEndDate")
   checkmate::assertChoice(order, c("first", "last"))
-  checkNameStyle(nameStyle, filterTbl, windowTbl, value)
   checkVariableInX(censorDate, x, TRUE, "censorDate")
 
   if (!is.null(censorDate)) {
@@ -95,12 +118,7 @@ addIntersect <- function(x,
     idName <- checkSnakeCase(idName)
   }
 
-  tablePrefix <- paste0(
-    "temp_",
-    c(sample(letters, 5, TRUE), "_") |> paste0(collapse = "")
-  )
-
-  startTibble <- x
+  tablePrefix <- omopgenerics::tmpPrefix()
 
   # define overlapTable that contains the events of interest
   overlapTable <- cdm[[tableName]]
@@ -113,11 +131,19 @@ addIntersect <- function(x,
     overlapTable <- dplyr::mutate(overlapTable, "id" = 1)
   }
 
+  values <- list(
+    "id_name" = filterTbl$id_name,
+    "window_name" = names(window),
+    "value" = value
+  )
+  assertNameStyle(nameStyle, values)
+  x <- warnOverwriteColumns(x = x, nameStyle = nameStyle, values = values)
+
   # columns that will be added
   newCols <- expand.grid(
     value = value,
     id_name = filterTbl$id_name,
-    window_name = windowTbl$window_name
+    window_name = names(window)
   ) %>%
     dplyr::as_tibble() %>%
     dplyr::mutate(colnam = as.character(glue::glue(
@@ -126,44 +152,48 @@ addIntersect <- function(x,
       id_name = .data$id_name,
       window_name = .data$window_name
     ))) %>%
-    dplyr::select("colnam", "value") %>%
     dplyr::mutate(colnam = checkSnakeCase(.data$colnam, verbose = F))
-  overwriteCols <- newCols$colnam[newCols$colnam %in% colnames(x)]
-  if (length(overwriteCols) > 0) {
-    cli::cli_warn("The following cols will be overwriten: {paste0(overwriteCols, collapse = ', ')}")
-    x <- x %>%
-      dplyr::select(-dplyr::all_of(overwriteCols))
-  }
 
   overlapTable <- overlapTable %>%
     dplyr::select(
       !!personVariable := dplyr::all_of(personVariableTable),
       "id" = dplyr::all_of(filterVariable),
-      "overlap_start_date" = dplyr::all_of(targetStartDate),
-      "overlap_end_date" = dplyr::all_of(targetEndDate %||% targetStartDate),
+      "start_date" = dplyr::all_of(targetStartDate),
+      "end_date" = dplyr::all_of(targetEndDate %||% targetStartDate),
       dplyr::all_of(extraValue)
     )
 
-  result <- x %>%
-    addFutureObservation(
-      indexDate = indexDate,
-      futureObservationName = "days_to_add"
-    ) %>%
-    dplyr::mutate("censor_date" = !!CDMConnector::dateadd(
-      indexDate, "days_to_add"
-    )) %>%
-    dplyr::mutate("censor_date" = .data[[censorDate %||% "censor_date"]])
-
-  result <- result %>%
+  result <- x |>
     dplyr::select(
       dplyr::all_of(personVariable),
       "index_date" = dplyr::all_of(indexDate),
-      "censor_date"
+      "censor_time" = dplyr::any_of(censorDate)
+    ) |>
+    addDemographics(
+      indexDate = "index_date", age = FALSE, sex = FALSE,
+      priorObservationName = "start_obs", futureObservationName = "end_obs"
     ) %>%
-    dplyr::distinct() %>%
+    dplyr::mutate("start_obs" = - .data$start_obs)
+  if (!is.null(censorDate)) {
+    result <- result %>%
+      dplyr::mutate(
+        "censor_time" = !!CDMConnector::datediff("index_date", "censor_time"),
+        "end_obs" = dplyr::if_else(
+          .data$censor_time < .data$end_obs, .data$censor_time, .data$end_obs
+      )) |>
+      dplyr::select(-"censor_time")
+  }
+  result <- result |>
     dplyr::inner_join(overlapTable, by = personVariable) %>%
+    dplyr::mutate(
+      "start" = !!CDMConnector::datediff("index_date", "start_date"),
+      "end" = !!CDMConnector::datediff("index_date", "end_date")
+    ) |>
+    dplyr::filter(
+      .data$start_obs <= .data$end & .data$start <= .data$end_obs
+    ) |>
     dplyr::compute(
-      name = paste0(tablePrefix, "individuals"),
+      name = omopgenerics::uniqueTableName(tablePrefix),
       temporary = FALSE,
       overwrite = TRUE
     )
@@ -172,54 +202,55 @@ addIntersect <- function(x,
   resultDateTimeOther <- NULL
   # Start loop for different windows
 
-  for (i in c(1:nrow(windowTbl))) {
-    resultW <- result
-    if (!is.infinite(windowTbl$upper[i])) {
-      resultW <- resultW %>%
-        dplyr::mutate(indicator = dplyr::if_else(.data$index_date >= as.Date(!!CDMConnector::dateadd(
-          date = "overlap_start_date", number = -windowTbl$upper[i]
-        )), 1, 0))
+  for (i in seq_along(window)) {
+    win <- window[[i]]
+    if (is.infinite(win[1])) {
+      if (is.infinite(win[2])) {
+        resultW <- result
+      } else {
+        resultW <- result %>% dplyr::filter(.data$end <= !!win[2])
+      }
     } else {
-      resultW <- resultW %>% dplyr::mutate(indicator = 1)
+      if (is.infinite(win[2])) {
+        resultW <- result %>% dplyr::filter(.data$start >= !!win[1])
+      } else {
+        resultW <- result %>%
+          dplyr::filter(.data$start >= !!win[1] & .data$end <= !!win[2])
+      }
     }
 
     resultW <- resultW %>%
-      dplyr::mutate(indicator = dplyr::if_else(.data$overlap_start_date > .data$censor_date,
-        0, .data$indicator
-      ))
-
-    if (!is.infinite(windowTbl$lower[i])) {
-      resultW <- resultW %>%
-        dplyr::mutate(indicator = dplyr::if_else(.data$index_date > as.Date(!!CDMConnector::dateadd(
-          date = "overlap_end_date", number = -windowTbl$lower[i]
-        )), 0, .data$indicator))
-    }
-    resultW <- resultW %>%
+      dplyr::select(-"end") |>
       dplyr::compute(
-        name = paste0(tablePrefix, "window"),
+        name = omopgenerics::uniqueTableName(tablePrefix),
         temporary = FALSE,
         overwrite = TRUE
       )
 
+    filterTblName <- omopgenerics::uniqueTableName(tablePrefix)
+    cdm <- omopgenerics::insertTable(
+      cdm = cdm, name = filterTblName, table = filterTbl, overwrite = TRUE
+    )
+
     # add count or flag
     if ("count" %in% value | "flag" %in% value) {
       resultCF <- resultW %>%
         dplyr::group_by(.data[[personVariable]], .data$index_date, .data$id) %>%
-        dplyr::summarise(count = sum(.data$indicator, na.rm = TRUE), .groups = "drop") %>%
-        dplyr::left_join(filterTbl, by = "id", copy = TRUE) %>%
+        dplyr::summarise(count = dplyr::n(), .groups = "drop") %>%
+        dplyr::left_join(cdm[[filterTblName]], by = "id") %>%
         dplyr::select(-"id") %>%
-        dplyr::mutate("window_name" = !!tolower(windowTbl$window_name[i]))
+        dplyr::mutate("window_name" = !!tolower(names(window)[i]))
       if ("flag" %in% value) {
-        resultCF <- resultCF %>% dplyr::mutate(flag = dplyr::if_else(.data$count > 0, 1, 0))
+        resultCF <- resultCF %>% dplyr::mutate(flag = 1)
       }
       if (!("count" %in% value)) {
-        resultCF <- dplyr::select(resultCF, -"count")
+        resultCF <- resultCF |> dplyr::select(-"count")
       }
 
       if (i == 1) {
         resultCountFlag <- resultCF %>%
           dplyr::compute(
-            name = paste0(tablePrefix, "win_count_flag"),
+            name = omopgenerics::uniqueTableName(tablePrefix),
             temporary = FALSE,
             overwrite = TRUE
           )
@@ -227,7 +258,7 @@ addIntersect <- function(x,
         resultCountFlag <- resultCountFlag |>
           dplyr::union_all(resultCF) |>
           dplyr::compute(
-            name = paste0(tablePrefix, "win_count_flag"),
+            name = omopgenerics::uniqueTableName(tablePrefix),
             temporary = FALSE,
             overwrite = TRUE
           )
@@ -236,19 +267,16 @@ addIntersect <- function(x,
     # add date, time or other
     if (length(value[!(value %in% c("count", "flag"))]) > 0) {
       resultDTO <- resultW %>%
-        dplyr::filter(.data$indicator == 1) %>%
         dplyr::group_by(.data[[personVariable]], .data$index_date, .data$id)
       if (order == "first") {
         resultDTO <- resultDTO %>%
           dplyr::summarise(
-            date = min(.data$overlap_start_date, na.rm = TRUE),
-            .groups = "drop"
+            days = min(.data$start, na.rm = TRUE), .groups = "drop"
           )
       } else {
         resultDTO <- resultDTO %>%
           dplyr::summarise(
-            date = max(.data$overlap_start_date, na.rm = TRUE),
-            .groups = "drop"
+            days = max(.data$start, na.rm = TRUE), .groups = "drop"
           )
       }
       resultDTO <- resultDTO %>%
@@ -258,11 +286,9 @@ addIntersect <- function(x,
             dplyr::distinct(),
           by = c(personVariable, "index_date", "id")
         )
-      if ("days" %in% value) {
+      if ("date" %in% value) {
         resultDTO <- resultDTO %>%
-          dplyr::mutate(
-            days = !!CDMConnector::datediff("index_date", "date", interval = "day")
-          )
+          dplyr::mutate(date = as.Date(!!CDMConnector::dateadd("index_date", "days")))
       }
       if (length(extraValue) > 0) {
         resultDTO <- resultDTO %>%
@@ -270,14 +296,14 @@ addIntersect <- function(x,
             resultW %>%
               dplyr::select(
                 dplyr::all_of(personVariable), "index_date", "id",
-                "date" = "overlap_start_date", dplyr::all_of(extraValue)
+                "days" = "start", dplyr::all_of(extraValue)
               ) %>%
               dplyr::inner_join(
                 resultDTO %>%
                   dplyr::select(dplyr::all_of(
-                    c(personVariable, "index_date", "id", "date")
+                    c(personVariable, "index_date", "id", "days")
                   )),
-                by = c(personVariable, "index_date", "id", "date")
+                by = c(personVariable, "index_date", "id", "days")
               ) %>%
               dplyr::group_by(.data[[personVariable]], .data$index_date, .data$id) %>%
               dplyr::summarise(
@@ -289,18 +315,18 @@ addIntersect <- function(x,
             by = c(personVariable, "index_date", "id")
           )
       }
-      resultDTO <- resultDTO %>%
-        dplyr::left_join(filterTbl, by = "id", copy = TRUE) %>%
-        dplyr::select(-"id") %>%
-        dplyr::mutate("window_name" = !!tolower(windowTbl$window_name[i]))
-      if (!("date" %in% value)) {
-        resultDTO <- dplyr::select(resultDTO, -"date")
-      }
 
+      resultDTO <- resultDTO %>%
+        dplyr::left_join(cdm[[filterTblName]], by = "id") %>%
+        dplyr::select(-"id") %>%
+        dplyr::mutate("window_name" = !!tolower(names(window)[i]))
+      if (!("days" %in% value)) {
+        resultDTO <- dplyr::select(resultDTO, -"days")
+      }
       if (i == 1) {
         resultDateTimeOther <- resultDTO %>%
           dplyr::compute(
-            name = paste0(tablePrefix, "win_date_days"),
+            name = omopgenerics::uniqueTableName(tablePrefix),
             temporary = FALSE,
             overwrite = TRUE
           )
@@ -308,7 +334,7 @@ addIntersect <- function(x,
         resultDateTimeOther <- resultDateTimeOther |>
           dplyr::union_all(resultDTO) |>
           dplyr::compute(
-            name = paste0(tablePrefix, "win_date_days"),
+            name = omopgenerics::uniqueTableName(tablePrefix),
             temporary = FALSE,
             overwrite = TRUE
           )
@@ -342,9 +368,9 @@ addIntersect <- function(x,
       ) %>%
       dplyr::mutate(dplyr::across(
         dplyr::all_of(newColCountFlag), ~ dplyr::if_else(is.na(.x), 0, .x)
-      )) %>%
+      )) |>
       dplyr::compute(
-        name = paste0(tablePrefix, "count_flag"),
+        name = omopgenerics::uniqueTableName(tablePrefix),
         temporary = FALSE,
         overwrite = TRUE
       )
@@ -379,7 +405,7 @@ addIntersect <- function(x,
 
     x <- x %>%
       dplyr::compute(
-        name = paste0(tablePrefix, "date_days"),
+        name = omopgenerics::uniqueTableName(tablePrefix),
         temporary = FALSE,
         overwrite = TRUE
       )
@@ -405,18 +431,47 @@ addIntersect <- function(x,
 
     newTib <- dplyr::tibble(!!id := 1)
     newTib[, cols] <- valk
+    tmpName <- omopgenerics::uniqueTableName(tablePrefix)
+    cdm <- omopgenerics::insertTable(cdm = cdm, name = tmpName, table = newTib)
 
     x <- x |>
       dplyr::mutate(!!id := 1) |>
-      dplyr::inner_join(newTib, copy = TRUE, by = id) |>
+      dplyr::inner_join(cdm[[tmpName]], by = id) |>
+      dplyr::select(!dplyr::all_of(id)) |>
       dplyr::compute(
-        name = paste0(tablePrefix, "_val"), temporary = FALSE, overwrite = TRUE
+        name = omopgenerics::uniqueTableName(tablePrefix),
+        temporary = FALSE,
+        overwrite = TRUE
       )
   }
 
+  if (any(value %in% c("count", "flag"))) {
+    for (k in seq_along(window)) {
+      tmpName <- "tmp_col_12345"
+      cols <- newCols |>
+        dplyr::filter(
+          .data$window_name == names(window)[k] &
+            .data$value %in% c("count", "flag")
+        ) |>
+        dplyr::pull("colnam")
+      x <- x |>
+        addInObservation(
+          indexDate = indexDate,
+          window = window[[k]],
+          completeInterval = F,
+          nameStyle = tmpName
+        ) |>
+        dplyr::mutate(dplyr::across(
+          .cols = dplyr::all_of(cols),
+          .fns = ~ dplyr::if_else(tmp_col_12345 == 0, as.numeric(NA), .)
+        )) |>
+        dplyr::select(!dplyr::all_of(tmpName))
+    }
+  }
+
   x <- dplyr::compute(x)
 
-  cdm <- omopgenerics::dropTable(
+  omopgenerics::dropTable(
     cdm = cdm, name = dplyr::starts_with(tablePrefix)
   )
 
@@ -425,9 +480,9 @@ addIntersect <- function(x,
 
 #' Get the name of the start date column for a certain table in the cdm
 #'
-#' @param tableName Name of the table
+#' @param tableName Name of the table.
 #'
-#' @return Name of the start date column in that table
+#' @return Name of the start date column in that table.
 #'
 #' @export
 #'
@@ -447,9 +502,9 @@ startDateColumn <- function(tableName) {
 
 #' Get the name of the end date column for a certain table in the cdm
 #'
-#' @param tableName Name of the table
+#' @param tableName Name of the table.
 #'
-#' @return Name of the end date column in that table
+#' @return Name of the end date column in that table.
 #'
 #' @export
 #'
@@ -469,9 +524,9 @@ endDateColumn <- function(tableName) {
 
 #' Get the name of the standard concept_id column for a certain table in the cdm
 #'
-#' @param tableName Name of the table
+#' @param tableName Name of the table.
 #'
-#' @return Name of the concept_id column in that table
+#' @return Name of the concept_id column in that table.
 #'
 #' @export
 #'
@@ -491,9 +546,9 @@ standardConceptIdColumn <- function(tableName) {
 
 #' Get the name of the source concept_id column for a certain table in the cdm
 #'
-#' @param tableName Name of the table
+#' @param tableName Name of the table.
 #'
-#' @return Name of the source_concept_id column in that table
+#' @return Name of the source_concept_id column in that table.
 #'
 #' @export
 #'
