@@ -17,3 +17,7 @@
 #' @importFrom omopgenerics suppress
 #' @export
 omopgenerics::suppress
+
+#' @importFrom omopgenerics settings
+#' @export
+omopgenerics::settings
