@@ -16,13 +16,13 @@
 
 #' Summarise characteristics of individuals
 #'
-#' @param cohort A cohort in the cdm
+#' @param cohort A cohort in the cdm.
 #' @param cdm A cdm reference.
-#' @param strata Stratification list
+#' @param strata Stratification list.
 #' @param demographics Whether to summarise demographics data.
 #' @param ageGroup A list of age groups.
 #' @param tableIntersect A list of arguments that uses addTableIntersect
-#' function to add variables to summarise
+#' function to add variables to summarise.
 #' @param cohortIntersect A list of arguments that uses addCohortIntersect
 #' function to add variables to summarise.
 #' @param conceptIntersect A list of arguments that uses addConceptIntersect
@@ -30,7 +30,7 @@
 #' @param otherVariables Other variables contained in cohort that you want to be
 #' summarised.
 #'
-#' @return A summary of the characteristics of the individuals
+#' @return A summary of the characteristics of the individuals.
 #'
 #' @export
 #'
@@ -44,12 +44,20 @@
 #'   cohort = cdm$cohort1,
 #'   ageGroup = list(c(0, 19), c(20, 39), c(40, 59), c(60, 79), c(80, 150)),
 #'   tableIntersect = list(
-#'     tableName = "visit_occurrence", value = "count", window = c(-365, -1)
+#'     "Number visits prior year" = list(
+#'       tableName = "visit_occurrence", value = "count", window = c(-365, -1)
+#'     )
 #'   ),
 #'   cohortIntersect = list(
-#'     targetCohortTable = "cohort2", value = "flag", window = c(-365, -1)
+#'     "Drugs prior year" = list(
+#'       targetCohortTable = "cohort2", value = "flag", window = c(-365, -1)
+#'     ),
+#'     "Conditions any time prior" = list(
+#'       targetCohortTable = "cohort2", value = "flag", window = c(-Inf, -1)
+#'     )
 #'   )
 #' )
+#' CDMConnector::cdmDisconnect(cdm = cdm)
 #' }
 summariseCharacteristics <- function(cohort,
                                      cdm = lifecycle::deprecated(),
@@ -136,7 +144,8 @@ summariseCharacteristics <- function(cohort,
 
   dic <- dplyr::tibble(
     short_name = character(), new_variable_name = character(),
-    new_variable_level = character(), table = character(), window = character()
+    new_variable_level = character(), table = character(), window = character(),
+    value = character(), result_type = character()
   )
   variables <- list()
 
@@ -162,7 +171,9 @@ summariseCharacteristics <- function(cohort,
           new_variable_name = names(ageGroup),
           new_variable_level = as.character(NA),
           table = as.character(NA),
-          window = as.character(NA)
+          window = as.character(NA),
+          value = as.character(NA),
+          result_type = "summarised_demographics"
         ))
       names(ageGroup) <- newNames
       demographicsCategorical <- c(demographicsCategorical, newNames)
@@ -175,7 +186,9 @@ summariseCharacteristics <- function(cohort,
         ),
         new_variable_level = as.character(NA),
         table = as.character(NA),
-        window = as.character(NA)
+        window = as.character(NA),
+        value = as.character(NA),
+        result_type = "summarised_demographics"
       ))
 
     # add demographics
@@ -212,8 +225,8 @@ summariseCharacteristics <- function(cohort,
     # update dictionary
     addDic <- updateDic(
       tableIntersect[[k]]$value, shortNames, fullNames,
-      arguments$tableName, paste("any", arguments$tableName),
-      arguments$tableName
+      arguments$tableName, NA_character_, arguments$tableName,
+      names(tableIntersect)[k], "summarised_table_intersect"
     )
     dic <- dic %>% dplyr::union_all(addDic)
 
@@ -225,12 +238,13 @@ summariseCharacteristics <- function(cohort,
         indexDate = arguments$indexDate,
         censorDate = arguments$censorDate,
         order = arguments$order,
+        targetStartDate = arguments$targetStartDate,
+        targetEndDate = arguments$targetEndDate,
         flag = arguments$flag,
         count = arguments$count,
         date = arguments$date,
         days = arguments$days,
         field = arguments$field,
-        overlap = arguments$overlap,
         nameStyle = "{value}_{table_name}_{window_name}"
       )
 
@@ -299,7 +313,8 @@ summariseCharacteristics <- function(cohort,
     # update dictionary
     addDic <- updateDic(
       cohortIntersect[[k]]$value, shortNamesWindow, fullNamesWindow,
-      shortNamesCohort, fullNamesCohort, arguments$targetCohortTable
+      shortNamesCohort, fullNamesCohort, arguments$targetCohortTable,
+      names(cohortIntersect)[k], "summarised_cohort_intersect"
     )
     dic <- dic %>% dplyr::union_all(addDic)
 
@@ -358,7 +373,8 @@ summariseCharacteristics <- function(cohort,
     # update dictionary
     addDic <- updateDic(
       conceptIntersect[[k]]$value, shortNamesWindow, fullNamesWindow,
-      shortNamesConcept, fullNamesConcept, NA_character_
+      shortNamesConcept, fullNamesConcept, NA_character_,
+      names(conceptIntersect)[k],"summarised_concept_intersect"
     )
     dic <- dic %>% dplyr::union_all(addDic)
 
@@ -372,10 +388,7 @@ summariseCharacteristics <- function(cohort,
         targetStartDate = arguments$targetStartDate,
         targetEndDate = arguments$targetEndDate,
         order = arguments$order,
-        flag = arguments$flag,
-        count = arguments$count,
-        date = arguments$date,
-        days = arguments$days,
+        value = arguments$value,
         nameStyle = "{value}_{concept_name}_{window_name}"
       )
 
@@ -396,14 +409,36 @@ summariseCharacteristics <- function(cohort,
 
   # detect other variables
   x <- variableTypes(cohort %>% dplyr::select(dplyr::all_of(otherVariables)))
+  datesVariables <- x %>%
+    dplyr::filter(.data$variable_type == "date") %>%
+    dplyr::pull("variable_name")
+  numericVariables <- x %>%
+    dplyr::filter(.data$variable_type %in% c("numeric", "integer")) %>%
+    dplyr::pull("variable_name")
+  binaryVariables <- numericVariables[
+    lapply(numericVariables, function(x) {
+      cohort |>
+        dplyr::select(dplyr::all_of(x)) |>
+        dplyr::distinct() |>
+        dplyr::pull() |>
+        binaryVariable()
+    }) |>
+      unlist()
+  ]
+  numericVariables  <- numericVariables[!numericVariables %in% binaryVariables]
+  categoricalVariables <- x %>%
+    dplyr::filter(.data$variable_type == "categorical") %>%
+    dplyr::pull("variable_name")
   variables <- variables |>
     updateVariables(
-      date = x %>% dplyr::filter(.data$variable_type == "date") %>% dplyr::pull("variable"),
-      numeric = x %>% dplyr::filter(.data$variable_type == "numeric") %>% dplyr::pull("variable"),
-      binary = x %>% dplyr::filter(.data$variable_type == "binary") %>% dplyr::pull("variable"),
-      categorical = x %>% dplyr::filter(.data$variable_type == "categorical") %>% dplyr::pull("variable")
+      date = datesVariables,
+      numeric = numericVariables,
+      binary = binaryVariables,
+      categorical = categoricalVariables
     )
 
+  variables <- variables[lengths(variables) > 0]
+
   cli::cli_alert_info("summarising data")
   # summarise results
   results <- cohort %>%
@@ -411,10 +446,11 @@ summariseCharacteristics <- function(cohort,
       group = list("cohort_name"),
       strata = strata,
       variables = variables,
-      functions = functions[names(variables)]
+      estimates = functions[names(variables)],
+      verbose = FALSE
     ) %>%
     addCdmName(cdm = cdm) %>%
-    dplyr::mutate(result_type = "summarised_characteristics")
+    dplyr::select(!"result_type")
 
   # rename variables
   results <- results %>%
@@ -432,6 +468,11 @@ summariseCharacteristics <- function(cohort,
         is.na(.data$new_variable_level),
         .data$variable_level,
         .data$new_variable_level
+      ),
+      "result_type" = dplyr::if_else(
+        is.na(.data$result_type),
+        "summarised_characteristics",
+        .data$result_type
       )
     ) %>%
     dplyr::select(-c(
@@ -442,40 +483,39 @@ summariseCharacteristics <- function(cohort,
       c("variable_name", "variable_level"),
       ~ stringr::str_to_sentence(gsub("_", " ", .x))
     )) %>%
-    dplyr::mutate(
-      "additional_name" = dplyr::case_when(
-        is.na(.data$table) & is.na(.data$window) ~ "overall",
-        !is.na(.data$table) & is.na(.data$window) ~ "table",
-        is.na(.data$table) & !is.na(.data$window) ~ "window",
-        !is.na(.data$table) & !is.na(.data$window) ~ "table and window"
-      ),
-      "additional_level" = dplyr::case_when(
-        is.na(.data$table) & is.na(.data$window) ~ "overall",
-        !is.na(.data$table) & is.na(.data$window) ~ .data$table,
-        is.na(.data$table) & !is.na(.data$window) ~ .data$window,
-        !is.na(.data$table) & !is.na(.data$window) ~ paste(
-          .data$table, "and", .data$window
-        )
-      )
-    ) |>
-    dplyr::select(-dplyr::any_of(c("table", "window"))) |>
-    dplyr::as_tibble()
-
-  # correct integers
-  integers <- results$estimate_value
-  integers[results$estimate_type == "date"] <- NA
-  integers <- as.numeric(integers)
-  results$estimate_type[
-    results$estimate_type == "numeric" & integers == floor(integers)
-  ] <- "integer"
-
-  results <- omopgenerics::newSummarisedResult(results)
+    visOmopResults::uniteAdditional(cols = c("table", "window", "value")) |>
+    dplyr::as_tibble() |>
+    omopgenerics::newSummarisedResult()
 
   cli::cli_alert_success("summariseCharacteristics finished!")
 
   return(results)
 }
 
+#' Summarise concept intersect with a cohort_table
+#'
+#' @param cohort A cohort in the cdm
+#' @param strata Stratification list
+#' @param conceptIntersect A list of arguments that uses addConceptIntersect
+#' function to add variables to summarise.
+#'
+#' @return A summary of the concept intersect of the individuals
+#'
+#' @export
+#'
+summariseConceptIntersect <- function(cohort,
+                                      conceptIntersect,
+                                      strata = list()) {
+  if (length(conceptIntersect) == 0) {
+    cli::cli_abort("Please provide at least one cocneptSet to insersect with.")
+  }
+  summariseCharacteristics(
+    cohort = cohort, strata = strata, demographics = FALSE, ageGroup = NULL,
+    tableIntersect = list(), cohortIntersect = list(),
+    conceptIntersect = conceptIntersect, otherVariables = character()
+  )
+}
+
 correctWindowName <- function(windowName) {
   id <- grepl("_to_", windowName)
   windowName[id] <- windowName[id] |>
@@ -539,7 +579,9 @@ updateDic <- function(value,
                       fullWindow,
                       shortCohort,
                       fullCohort,
-                      tableName) {
+                      tableName,
+                      nam,
+                      resultType) {
   expand.grid("value" = value, "short_window" = shortWindow) %>%
     dplyr::as_tibble() %>%
     dplyr::inner_join(
@@ -559,20 +601,18 @@ updateDic <- function(value,
       .data$value, "_", .data$short_cohort, "_", .data$short_window
     )) %>%
     dplyr::mutate(
-      "new_variable_name" = dplyr::if_else(
-        .data$value %in% c("flag", "count", "date", "days"),
-        .data$full_cohort,
-        .data$value
-      ),
+      "new_variable_name" = .env$nam,
       "new_variable_level" = dplyr::if_else(
         .data$value %in% c("flag", "count", "date", "days"),
-        .data$value,
+        .data$full_cohort,
         as.character(NA)
       ),
       "table" = .env$tableName,
-      "window" = correctWindowName(.data$full_window)
+      "window" = correctWindowName(.data$full_window),
+      "result_type" = resultType
     ) |>
     dplyr::select(
-      "short_name", "new_variable_name", "new_variable_level", "table", "window"
+      "short_name", "new_variable_name", "new_variable_level", "table",
+      "window", "value", "result_type"
     )
 }
