@@ -36,6 +36,29 @@
 #'
 #' @export
 #'
+#' @examples
+#' \donttest{
+#' library(PatientProfiles)
+#' cdm <- PatientProfiles::mockPatientProfiles()
+#'
+#' concept <- dplyr::tibble(
+#' concept_id = c(1125315, 1503328, 1516978, 317009, 378253, 4266367),
+#' domain_id = NA_character_,
+#' vocabulary_id = NA_character_,
+#' concept_class_id = NA_character_,
+#' concept_code = NA_character_,
+#' valid_start_date = as.Date("1900-01-01"),
+#' valid_end_date = as.Date("2099-01-01")
+#' ) %>%
+#'  dplyr::mutate(concept_name = paste0("concept: ", .data$concept_id))
+#' cdm <- CDMConnector::insertTable(cdm, "concept", concept)
+#' results <- cdm$cohort2 %>%
+#' summariseLargeScaleCharacteristics(
+#'  episodeInWindow = c("condition_occurrence"),
+#'  minimumFrequency = 0
+#'  )
+#' CDMConnector::cdmDisconnect(cdm = cdm)
+#' }
 summariseLargeScaleCharacteristics <- function(cohort,
                                                strata = list(),
                                                window = list(
@@ -49,7 +72,7 @@ summariseLargeScaleCharacteristics <- function(cohort,
                                                censorDate = NULL,
                                                includeSource = FALSE,
                                                minimumFrequency = 0.005,
-                                               excludedCodes = NULL,
+                                               excludedCodes = c(0),
                                                cdm = lifecycle::deprecated()) {
   if (!is.list(window)) {
     window <- list(window)
@@ -80,7 +103,7 @@ summariseLargeScaleCharacteristics <- function(cohort,
   names(window) <- gsub("_", " ", gsub("m", "-", getWindowNames(window)))
 
   # random tablePrefix
-  tablePrefix <- c(sample(letters, 5, TRUE), "_") %>% paste0(collapse = "")
+  tablePrefix <- omopgenerics::tmpPrefix()
 
   # initial table
   x <- getInitialTable(cohort, tablePrefix, indexDate, censorDate)
@@ -151,13 +174,15 @@ summariseLargeScaleCharacteristics <- function(cohort,
       "estimate_name" = .data$estimate_type,
       "estimate_value" = .data$estimate,
       "estimate_type" = dplyr::if_else(
-        .data$estimate_type == "count", "numeric", "percentage"
+        .data$estimate_type == "count", "integer", "percentage"
       )
     ) |>
-    visOmopResults::uniteAdditional(
-      cols = c("table_name", "type", "analysis", "concept")
-    ) |>
+    dplyr::rename("concept_id" = "concept") |>
+    visOmopResults::uniteAdditional(cols = c("concept_id")) |>
+    dplyr::select(!c("estimate", "variable")) |>
+    appendSettings(colsSettings = c("table_name", "type", "analysis")) |>
     dplyr::select(dplyr::all_of(c(
+      "result_id",
       "cdm_name", "result_type", "package_name", "package_version",
       "group_name", "group_level", "strata_name", "strata_level",
       "variable_name", "variable_level", "estimate_name", "estimate_type",
@@ -182,14 +207,25 @@ summariseLargeScaleCharacteristics <- function(cohort,
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
 #' @param censorDate whether to censor overlap events at a specific date
-#' or a column date of x
+#' or a column date of x.
 #' @param minimumFrequency Minimum frequency covariates to report.
 #' @param excludedCodes Codes excluded.
 #'
 #' @return The output of this function is the cohort with the new created
-#' columns
+#' columns.
 #'
 #' @export
+#' @examples
+#' \donttest{
+#' library(PatientProfiles)
+#' cdm <- PatientProfiles::mockPatientProfiles()
+#' results <- cdm$cohort2 %>%
+#'   addLargeScaleCharacteristics(
+#'   episodeInWindow = c("condition_occurrence"),
+#'   minimumFrequency = 0
+#'   )
+#' CDMConnector::cdmDisconnect(cdm = cdm)
+#' }
 #'
 addLargeScaleCharacteristics <- function(cohort,
                                          window = list(c(0, Inf)),
@@ -204,6 +240,7 @@ addLargeScaleCharacteristics <- function(cohort,
   }
 
   cdm <- omopgenerics::cdmReference(cohort)
+  tablePrefix <- omopgenerics::tmpPrefix()
 
   # initial checks
   checkX(cohort)
@@ -228,8 +265,10 @@ addLargeScaleCharacteristics <- function(cohort,
   dic <- dplyr::tibble(window_name = nams, window_nam = paste0("lsc_", winNams))
   names(window) <- nams
 
-  # random tablePrefix
-  tablePrefix <- c(sample(letters, 5, TRUE), "_") %>% paste0(collapse = "")
+  dicTblName <- omopgenerics::uniqueTableName(tablePrefix)
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = dicTblName, table = dic, overwrite = TRUE
+  )
 
   # initial table
   x <- getInitialTable(cohort, tablePrefix, indexDate, censorDate)
@@ -273,7 +312,7 @@ addLargeScaleCharacteristics <- function(cohort,
         dplyr::select(
           "subject_id", "cohort_start_date", "concept", "window_name"
         ) %>%
-        dplyr::inner_join(dic, by = "window_name", copy = TRUE) %>%
+        dplyr::inner_join(cdm[[dicTblName]], by = "window_name") %>%
         dplyr::mutate(
           value = 1,
           concept = as.character(as.integer(.data$concept)),
@@ -402,6 +441,7 @@ getTable <- function(tab, x, includeSource, minWindow, maxWindow, tablePrefix, e
       cdm = cdm, name = nm, table = dplyr::tibble("standard" = excludedCodes),
       overwrite = TRUE
     )
+    cdm[[nm]] <- cdm[[nm]] |> dplyr::compute()
     table <- table |>
       dplyr::anti_join(cdm[[nm]], by = "standard")
     if ("source" %in% colnames(table)) {
@@ -419,7 +459,6 @@ getTable <- function(tab, x, includeSource, minWindow, maxWindow, tablePrefix, e
       overwrite = TRUE
     )
 }
-
 summariseConcept <- function(cohort, tableWindow, strata, tablePrefix) {
   result <- NULL
   cohortNames <- omopgenerics::settings(cohort)$cohort_name
@@ -495,7 +534,7 @@ formatLscResult <- function(lsc, den, cdm, minimumFrequency) {
         "window_name"
       )
     ) %>%
-    dplyr::mutate(percentage = 100 * .data$count / .data$denominator) %>%
+    dplyr::mutate(percentage = round(100 * .data$count / .data$denominator, 2)) %>%
     dplyr::select(-"denominator") %>%
     dplyr::filter(.data$percentage >= 100 * .env$minimumFrequency) %>%
     tidyr::pivot_longer(
@@ -519,15 +558,24 @@ addConceptName <- function(lsc, cdm) {
   concepts <- lsc %>%
     dplyr::select("concept", "analysis") %>%
     dplyr::distinct()
+
+  conceptsTblName <- omopgenerics::uniqueTableName(omopgenerics::tmpPrefix())
+  cdm <- omopgenerics::insertTable(cdm = cdm,
+                                   name = conceptsTblName,
+                                   table = concepts,
+                                   overwrite = TRUE )
+
   conceptNames <- cdm[["concept"]] %>%
     dplyr::select("concept" = "concept_id", "concept_name") %>%
     dplyr::inner_join(
-      concepts %>%
+      cdm[[conceptsTblName]] %>%
         dplyr::mutate(concept = as.numeric(.data$concept)),
-      by = "concept",
-      copy = TRUE
+      by = "concept"
     ) %>%
     dplyr::collect()
+
+  omopgenerics::dropTable(cdm = cdm, name = conceptsTblName)
+
   return(conceptNames)
 }
 getTableAnalysis <- function(table, type, analysis, tablePrefix) {
@@ -637,3 +685,46 @@ trimCounts <- function(lsc, tableWindow, minimumCount, tablePrefix, winName) {
   }
   return(lsc)
 }
+appendSettings <- function(results, colsSettings) {
+  ids <- results |>
+    dplyr::select(dplyr::all_of(colsSettings)) |>
+    dplyr::distinct() |>
+    dplyr::mutate("result_id" = as.integer(dplyr::row_number()))
+  results <- results |>
+    dplyr::left_join(ids, by = colsSettings) |>
+    dplyr::select(!dplyr::all_of(colsSettings))
+  settingsIds <- ids |>
+    tidyr::pivot_longer(
+      cols = dplyr::all_of(colsSettings),
+      names_to = "estimate_name",
+      values_to = "estimate_value"
+    ) |>
+    dplyr::inner_join(
+      variableTypes(ids) |>
+        dplyr::select(
+          "estimate_name" = "variable_name", "estimate_type" = "variable_type"
+        ) |>
+        dplyr::mutate("estimate_type" = dplyr::if_else(
+          .data$estimate_type == "categorical", "character", .data$estimate_type
+        )),
+      by = "estimate_name"
+    ) |>
+    dplyr::mutate(
+      "variable_name" = "settings",
+      "variable_level" = NA_character_,
+      "group_name" = "overall",
+      "group_level" = "overall",
+      "strata_name" = "overall",
+      "strata_level" = "overall",
+      "additional_name" = "overall",
+      "additional_level" = "overall",
+      "package_name" = results$package_name[1],
+      "package_version" = results$package_version[1],
+      "result_type" = results$result_type[1],
+      "cdm_name" = results$cdm_name[1]
+    )
+  results <- settingsIds |>
+    dplyr::union_all(results) |>
+    dplyr::arrange(.data$result_id)
+  return(results)
+}
